==> haskell-text-metrics-0.3.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-metrics
version: 0.3.0
id: text-metrics-0.3.0-FDxATb53U0D25DaBchqZg3
key: text-metrics-0.3.0-FDxATb53U0D25DaBchqZg3
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/text-metrics
synopsis: Calculate various string metrics efficiently
description:
    Calculate various string metrics efficiently.
category: Text, Algorithms
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Metrics
abi: 16371d3a8c87ee369448d9ba3101630b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-metrics-0.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-metrics-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/text-metrics-0.3.0
hs-libraries: HStext-metrics-0.3.0-FDxATb53U0D25DaBchqZg3
depends:
    base-4.10.1.0 containers-0.5.10.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
haddock-interfaces: /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock
haddock-html: /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-metrics-0.3.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-metrics
version: 0.3.0
id: text-metrics-0.3.0-Ln7xHEJ8TUI5J1G7y63m6t
key: text-metrics-0.3.0-Ln7xHEJ8TUI5J1G7y63m6t
license: BSD3
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/text-metrics
synopsis: Calculate various string metrics efficiently
description:
    Calculate various string metrics efficiently.
category: Text, Algorithms
author: Mark Karpov <markkarpov92@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Metrics
abi: 1687f2f8090f0e76eb82e362d40e496e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-metrics-0.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-metrics-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/text-metrics-0.3.0
hs-libraries: HStext-metrics-0.3.0-Ln7xHEJ8TUI5J1G7y63m6t
depends:
    base-4.10.1.0 containers-0.5.10.2
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
haddock-interfaces: /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock
haddock-html: /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
